Nous.Research.Reporter (nous v0.13.3)

Generates structured research reports with citations.

Summary

Functions

Generate a markdown report from synthesis results and findings.

Functions

generate(query, synthesis, findings, opts \\ [])

@spec generate(String.t(), map(), [Nous.Research.Finding.t()], keyword()) ::
  {:ok, Nous.Research.Report.t()} | {:error, term()}

Generate a markdown report from synthesis results and findings.