Nous.Research.Synthesizer (nous v0.13.3)
View SourceConsolidates findings from multiple searchers.
Performs deduplication, contradiction detection, and gap analysis.
Summary
Functions
Synthesize findings from multiple search results into a consolidated view.
Types
Functions
@spec synthesize( [Nous.Research.Finding.t()], keyword() ) :: {:ok, synthesis()} | {:error, term()}
Synthesize findings from multiple search results into a consolidated view.