Nous.Tools.FileRead (nous v0.13.3)
View SourceFile reading tool with line numbers.
Returns file content with cat -n style line numbers, supporting
offset and limit for reading specific sections of large files.
File reading tool with line numbers.
Returns file content with cat -n style line numbers, supporting
offset and limit for reading specific sections of large files.