Nous.Tools.FileEdit (nous v0.13.3)
View SourceString replacement editing tool.
Edits files by finding and replacing exact string matches.
By default requires old_string to be unique in the file
to prevent unintended changes.
String replacement editing tool.
Edits files by finding and replacing exact string matches.
By default requires old_string to be unique in the file
to prevent unintended changes.