Nous.Tools.FileGrep (nous v0.13.3)
View SourceContent search tool.
Searches file contents using regex patterns. Uses ripgrep (rg)
when available for performance, falls back to pure Elixir regex.
Content search tool.
Searches file contents using regex patterns. Uses ripgrep (rg)
when available for performance, falls back to pure Elixir regex.